@@ -1,26 +1,40 @@
-from msilib.schema import Patch
+#from msilib.schema import Patch
 import pathlib
 from os import path
+import os
 import base64
-import re
+import sys
+import toml
+import tomli
+import json
+from jsonschema import validate as valid
 from .parser.Question import CodeRunner
 from .parser.Question import MultipleChoice
 from .parser.TestCase import TestCase
 from .parser.Answer import Answer
 from .parser.Question import ShortAnswer
+from .parser.Question import Description
 from .parser.File import File
 from .parser.Category import Category
 from jinja2 import Environment, FileSystemLoader
 from datetime import datetime
 
-def validate(fileLines):
-    pass
-    #print("Content:", fileLines)
+__location__ = os.path.realpath(
+    os.path.join(os.getcwd(), os.path.dirname(__file__)))
+
+def validate(file, dir):
+
+    with open(os.path.join(__location__, "schema.json")) as f:
+        schema = json.loads(f.read())
+        tomlFile = tomli.loads(file)
+        tomlFile = json.dumps(tomlFile)
+        tomlFile = json.loads(tomlFile)
+        valid(instance=tomlFile, schema=schema)
+        
 
 
 def getQuestion(dir):
-    print("[{}] Loading questions from {}".format(datetime.now().strftime("%H:%M:%S"), dir))
-
+    print("[{}] Loading question from {}".format(datetime.now().strftime("%H:%M:%S"), dir))
     if dir.suffix == ".cr":
         print("[{}]   Question format: CodeRunner".format(datetime.now().strftime("%H:%M:%S")))
         newQuestion = CodeRunner()
@@ -29,6 +43,10 @@ def getQuestion(dir):
         newQuestion = MultipleChoice()
     elif dir.suffix == ".sa":
         newQuestion = ShortAnswer()
+    elif dir.suffix == ".de":
+        newQuestion = Description()
+    else:
+        print(dir.suffix)
     for p in dir.iterdir():
         if not p.is_file():
             for sf in p.iterdir():
@@ -42,7 +60,6 @@ def getQuestion(dir):
                         else:
                             newQuestion.addFile(newFile)
             continue
-
         with open(p) as f:
             if p.suffix == ".py":
                 print("[{}]   Input format: .py".format(datetime.now().strftime("%H:%M:%S")))
@@ -60,9 +77,9 @@ def getQuestion(dir):
                 newQuestion.setFeedback(feedback)
 
             elif p.suffix == ".toml":
+                validate(f.read(), dir)
+                f.seek(0)
                 fileRead = f.readlines()
-                #Validation
-                validate(fileRead)
                 print("[{}]   Input format: .toml".format(datetime.now().strftime("%H:%M:%S")))
 
                 cases = []
@@ -157,7 +174,6 @@ def importQuestions(root, globPattern):
             continue
         break
 
-    print("pathToTemplates =", path.join(path.dirname(__file__), 'templates'))
     file_loader = FileSystemLoader(path.join(path.dirname(__file__), 'templates'))
 
     env = Environment(loader=file_loader)
